import argparse
from pathlib import Path
import os

from seq_exec import run_sequential
from concurrency_exec import run_concurrent
from utils import gen_binary_file, measure

def _get_parser():
    parser = argparse.ArgumentParser(description="Python dummy benchmark")
    parser.add_argument('mode', choices=["seq", "concurrent"])
    parser.add_argument('--files', type=int, default=5)
    parser.add_argument('--nums-per-file', type=int, default=1000)
    return parser

def generate_single_file(f, nums_per_file):
    aux = Path(f"{f}_input.bin")
    if aux.exists():
        os.remove(aux)
    gen_binary_file(aux, nums_per_file)

@measure
def generate_inputs_seq(n_files, nums_per_file):
    for f in range(n_files):
        generate_single_file(f, nums_per_file)

def main():
    # PARSE ARGS:
    args = _get_parser().parse_args()
    
    mode = args.mode
    num_files = args.files
    numbers_per_file = args.nums_per_file
    problem_size = num_files * numbers_per_file

    if problem_size % 2 != 0:
        print("problem_size must be divisible by 2")

    # GENERATE INPUTS (if not created already)
    print("STARTING PYTHON DUMMY BENCHMARK")
    print("MODE: {}, NUM_FILES: {} numbers_per_file: {} ".
          format(mode, num_files, numbers_per_file))

    generate_inputs_seq(num_files, numbers_per_file)
    if mode == "seq":
        run_sequential(num_files)
    elif mode == "concurrent":
        run_concurrent(num_files)
    else:
        print(f"MODE {mode} NOT RECOGNIZED")
    print("ENDING")

if __name__ == "__main__":
    main()

